==> qucs-s-debug-2.1.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-2.1.0/builddir/converter/parse_dataset.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_DATASET_BUILD_QUCS_S_SRC_QUCS_S_2_1_0_BUILDDIR_CONVERTER_PARSE_DATASET_HPP_INCLUDED
# define YY_DATASET_BUILD_QUCS_S_SRC_QUCS_S_2_1_0_BUILDDIR_CONVERTER_PARSE_DATASET_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int dataset_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    InvalidCharacter = 258,        /* InvalidCharacter  */
    Identifier = 259,              /* Identifier  */
    REAL = 260,                    /* REAL  */
    IMAG = 261,                    /* IMAG  */
    COMPLEX = 262,                 /* COMPLEX  */
    Integer = 263,                 /* Integer  */
    Eol = 264,                     /* Eol  */
    IndepBegin = 265,              /* IndepBegin  */
    DepBegin = 266,                /* DepBegin  */
    IndepEnd = 267,                /* IndepEnd  */
    DepEnd = 268,                  /* DepEnd  */
    Version = 269                  /* Version  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 70 "/build/qucs-s/src/qucs-s-2.1.0/converter/parse_dataset.ypp"

  char * ident;
  double f;
  struct {
    double r;
    double i;
  } c;
  long n;
  qucs::vector * v;
  qucs::dataset * data;
  qucs::strlist * list;

#line 91 "/build/qucs-s/src/qucs-s-2.1.0/builddir/converter/parse_dataset.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE dataset_lval;


int dataset_parse (void);


#endif /* !YY_DATASET_BUILD_QUCS_S_SRC_QUCS_S_2_1_0_BUILDDIR_CONVERTER_PARSE_DATASET_HPP_INCLUDED  */

==> qucs-s-debug-24.1.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.1.0/builddir/converter/parse_dataset.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_DATASET_BUILD_QUCS_S_SRC_QUCS_S_24_1_0_BUILDDIR_CONVERTER_PARSE_DATASET_HPP_INCLUDED
# define YY_DATASET_BUILD_QUCS_S_SRC_QUCS_S_24_1_0_BUILDDIR_CONVERTER_PARSE_DATASET_HPP_INCLUDED
/* Debug traces.  */
#ifndef DATASET_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define DATASET_DEBUG 1
#  else
#   define DATASET_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define DATASET_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined DATASET_DEBUG */
#if DATASET_DEBUG
extern int dataset_debug;
#endif

/* Token kinds.  */
#ifndef DATASET_TOKENTYPE
# define DATASET_TOKENTYPE
  enum dataset_tokentype
  {
    DATASET_EMPTY = -2,
    DATASET_EOF = 0,               /* "end of file"  */
    DATASET_error = 256,           /* error  */
    DATASET_UNDEF = 257,           /* "invalid token"  */
    InvalidCharacter = 258,        /* InvalidCharacter  */
    Identifier = 259,              /* Identifier  */
    REAL = 260,                    /* REAL  */
    IMAG = 261,                    /* IMAG  */
    COMPLEX = 262,                 /* COMPLEX  */
    Integer = 263,                 /* Integer  */
    Eol = 264,                     /* Eol  */
    IndepBegin = 265,              /* IndepBegin  */
    DepBegin = 266,                /* DepBegin  */
    IndepEnd = 267,                /* IndepEnd  */
    DepEnd = 268,                  /* DepEnd  */
    Version = 269                  /* Version  */
  };
  typedef enum dataset_tokentype dataset_token_kind_t;
#endif

/* Value type.  */
#if ! defined DATASET_STYPE && ! defined DATASET_STYPE_IS_DECLARED
union DATASET_STYPE
{
#line 70 "/build/qucs-s/src/qucs-s-24.1.0/converter/parse_dataset.ypp"

  char * ident;
  double f;
  struct {
    double r;
    double i;
  } c;
  long n;
  qucs::vector * v;
  qucs::dataset * data;
  qucs::strlist * list;

#line 99 "/build/qucs-s/src/qucs-s-24.1.0/builddir/converter/parse_dataset.hpp"

};
typedef union DATASET_STYPE DATASET_STYPE;
# define DATASET_STYPE_IS_TRIVIAL 1
# define DATASET_STYPE_IS_DECLARED 1
#endif


extern DATASET_STYPE dataset_lval;


int dataset_parse (void);


#endif /* !YY_DATASET_BUILD_QUCS_S_SRC_QUCS_S_24_1_0_BUILDDIR_CONVERTER_PARSE_DATASET_HPP_INCLUDED  */
